###############################################################################
#
# Tests for XlsxWriter.
#
# SPDX-License-Identifier: BSD-2-Clause
# Copyright (c), 2013-2021, John McNamara, jmcnamara@cpan.org
#

from ..excel_comparison_test import ExcelComparisonTest
from ...workbook import Workbook


class TestCompareXLSXFiles(ExcelComparisonTest):
    """
    Test file created by XlsxWriter against a file created by Excel.

    """

    def setUp(self):

        self.set_filename('repeat05.xlsx')

        self.ignore_files = ['xl/printerSettings/printerSettings1.bin',
                             'xl/printerSettings/printerSettings2.bin',
                             'xl/worksheets/_rels/sheet1.xml.rels',
                             'xl/worksheets/_rels/sheet3.xml.rels']
        self.ignore_elements = {'[Content_Types].xml': ['<Default Extension="bin"'],
                                'xl/worksheets/sheet1.xml': ['<pageMargins', '<pageSetup'],
                                'xl/worksheets/sheet3.xml': ['<pageMargins', '<pageSetup']}

    def test_create_file(self):
        """Test the creation of a simple XlsxWriter file with repeat rows and cols on more than one worksheet."""

        workbook = Workbook(self.got_filename)

        worksheet1 = workbook.add_worksheet()
        worksheet2 = workbook.add_worksheet()
        worksheet3 = workbook.add_worksheet()

        worksheet1.repeat_rows(0)
        worksheet3.repeat_rows(2, 3)
        worksheet3.repeat_columns('B:F')

        worksheet1.write('A1', 'Foo')

        workbook.close()

        self.assertExcelEqual()
